@@ -3,7 +3,8 @@ Module that use sklearn library to compute mostly time series predictions.
 
 For model structure info, check models module docstrings - share structure with other models.
 
-If main train function is optimized in best_params module (automatic best regressor choose), it can use function `get_all_models()` that return all existing regressor.
+If main train function is optimized in best_params module (automatic best regressor choose),
+it can use function ``get_all_models()`` that return all existing regressor.
 """
 
 import mylogging
@@ -35,37 +36,22 @@ def train(
     activation_func="selu"
     #  load_trained_model=0, update_trained_model=1, save_model=1, saved_model_path_string='stored_models',
 ):
-    """Sklearn model. Models as input parameter. Can be linear, ridge, or Huber or much more.
+    """Sklearn model. Models as input parameter. Can be linear, ridge, Huber or much more.
     It also contain extreme learning machine model from sklearn extensions.
 
     Note:
-        There are many parameters in function, but all models use just a few of them. If you are using hyperparameter optimization
-        (for example optimize from `best_params` module) use only such a parameters that are used in particular models.
-        Usually default parameters are sufficient and optimizing is good moslty for selecting optimal model. You can use
-        `get_all_models` function to get all models and `optimize` for choosing the best one.
+        There are many parameters in function, but all models use just a few of them.
+        Usually default parameters are just enough.
+
+        Some of models are regressors and some are classifiers. If it's classifier, it's optimal
+        to have data sorted in limited number of bins.
 
     Args:
         data ((np.ndarray, np.ndarray)) - Tuple (X, y) of input train vectors X and train outputs y.
-            Insert input with no constant column - added by default in sklearn. Check mydatapreprocessings how to generate output.
-        model ((str, object), optional): Model that will be used. You can insert model itself or just a name of used class.
-            Options if string:
-                ['PLSRegression', 'RandomForestRegressor', 'ExtraTreesRegressor', 'BaggingRegressor', 'GradientBoostingRegressor', 'AdaBoostRegressor',
-                'VotingRegressor', 'StackingRegressor', 'RandomForestClassifier', 'ExtraTreesClassifier', 'BaggingClassifier', 'GradientBoostingClassifier',
-                'AdaBoostClassifier', 'VotingClassifier', 'StackingClassifier', 'GaussianProcessRegressor', 'GaussianProcessClassifier', 'IsotonicRegression',
-                Regression', 'HuberRegressor', 'LinearRegression', 'LogisticRegression', 'LogisticRegressionCV', 'PassiveAggressiveRegressor',
-                'SGDRegressor', 'TheilSenRegressor', 'RANSACRegressor', 'PoissonRegressor', 'GammaRegressor', 'TweedieRegressor',
-                'PassiveAggressiveClassifier', 'RidgeClassifier', 'RidgeClassifierCV', 'SGDClassifier', 'OneVsRestClassifier', 'OneVsOneClassifier',
-                'OutputCodeClassifier', 'MultiOutputRegressor', 'RegressorChain', 'MultiOutputClassifier', 'ClassifierChain', 'KNeighborsRegressor',
-                'RadiusNeighborsRegressor', 'KNeighborsClassifier', 'RadiusNeighborsClassifier', 'MLPRegressor', 'MLPClassifier', 'SelfTrainingClassifier',
-                'DecisionTreeRegressor', 'ExtraTreeRegressor', 'DecisionTreeClassifier', 'ExtraTreeClassifier', 'TransformedTargetRegressor', 'BayesianRidge',
-                'ElasticNet', 'Hinge', 'Lars', 'LarsCV', 'Lasso', 'LassoCV', 'LassoLarsIC', 'Log', 'ModifiedHuber', 'MultiTaskElasticNet', 'MultiTaskLasso',
-                'MultiTaskLassoCV', 'OrthogonalMatchingPursuit', 'OrthogonalMatchingPursuitCV', 'Perceptron', 'Ridge', 'RidgeCV', 'SquaredLoss', 'SVR',
-                # Sklearn extensions
-                'ELMClassifier', 'ELMRegressor', 'GenELMClassifier', 'GenELMRegressor'
-                ]
-            Defaults to 'BayesianRidge'.
-        type ('regressor', optional): If using model as string name, define whether 'regressor' or 'classifier' class will be used.
-            If using classifier, data must be binned. Defaults to 'regressor'.
+            Insert input with no constant column - added by default in sklearn.
+            Check `mydatapreprocessing` how to generate output.
+        model ((str, object), optional): Model that will be used. You can insert model itself or
+            just a name of used class. All possible options below in docs. Defaults to 'BayesianRidge'.
         n_estimators (100, optional):  Parameter of some model. Defaults to 100.
         alpha (float, optional): Parameter of some model. Defaults to 0.0001.
         alpha_1 (float, optional): Parameter of some model. Defaults to 1.e-6.
@@ -83,11 +69,38 @@ def train(
 
     Returns:
         np.ndarray: Predictions of input time series.
+
+    Options if string::
+
+        ['PLSRegression', 'RandomForestRegressor', 'ExtraTreesRegressor', 'BaggingRegressor',
+        'GradientBoostingRegressor', 'AdaBoostRegressor', 'VotingRegressor', 'StackingRegressor',
+        'RandomForestClassifier', 'ExtraTreesClassifier', 'BaggingClassifier', 'GradientBoostingClassifier',
+        'AdaBoostClassifier', 'VotingClassifier', 'StackingClassifier', 'GaussianProcessRegressor',
+        'GaussianProcessClassifier', 'IsotonicRegression', Regression', 'HuberRegressor', 'LinearRegression',
+        'LogisticRegression', 'LogisticRegressionCV', 'PassiveAggressiveRegressor', 'SGDRegressor',
+        'TheilSenRegressor', 'RANSACRegressor', 'PoissonRegressor', 'GammaRegressor', 'TweedieRegressor',
+        'PassiveAggressiveClassifier', 'RidgeClassifier', 'RidgeClassifierCV', 'SGDClassifier', 'OneVsRestClassifier',
+        'OneVsOneClassifier', 'OutputCodeClassifier', 'MultiOutputRegressor', 'RegressorChain',
+        'MultiOutputClassifier', 'ClassifierChain', 'KNeighborsRegressor', 'RadiusNeighborsRegressor',
+        'KNeighborsClassifier', 'RadiusNeighborsClassifier', 'MLPRegressor', 'MLPClassifier',
+        'SelfTrainingClassifier', 'DecisionTreeRegressor', 'ExtraTreeRegressor', 'DecisionTreeClassifier',
+        'ExtraTreeClassifier', 'TransformedTargetRegressor', 'BayesianRidge', 'ElasticNet', 'Hinge', 'Lars', 'LarsCV',
+        'Lasso', 'LassoCV', 'LassoLarsIC', 'Log', 'ModifiedHuber', 'MultiTaskElasticNet', 'MultiTaskLasso',
+        'MultiTaskLassoCV', 'OrthogonalMatchingPursuit', 'OrthogonalMatchingPursuitCV', 'Perceptron', 'Ridge',
+        'RidgeCV', 'SquaredLoss', 'SVR',
+        # Sklearn extensions
+        'ELMClassifier', 'ELMRegressor', 'GenELMClassifier', 'GenELMRegressor']
     """
+    from sklearn import (
+        multioutput,
+        linear_model,
+        ensemble,
+        tree,
+        neighbors,
+        gaussian_process,
+    )
 
-    from sklearn import multioutput, linear_model, ensemble, tree, neighbors, gaussian_process
-
-    # If strings, find class with such a name
+    # If string like 'LinearRegression', find class with such a name
     if isinstance(model, str):
 
         for i in [linear_model, ensemble, tree, neighbors, gaussian_process]:
@@ -95,20 +108,22 @@ def train(
                 model = getattr(i, model)
                 break
 
-        # If model is stil string, not object from sklearn, it means it was not found
+        # If model is still string, not object from sklearn, it means it was not found,
+        # may be from sklearnextensions library
         if isinstance(model, str):
 
             import sklearn_extensions.extreme_learning_machines.elm as elm
 
             model = getattr(elm, model)
 
+            # Model defined by string not found
             if isinstance(model, str):
 
                 raise AttributeError(
                     mylogging.return_str(
                         "You defined model that was not found in sklearn. You can use not only string, but also"
-                        "object or class itself. You can use function `get_all_models` to get list of all possible models"
-                        "and then use one of them."
+                        "object or class itself. You can use function `get_all_models` to get list of all"
+                        "possible models and then use one of them."
                     )
                 )
 
@@ -160,7 +175,9 @@ def predict(x_input, model, predicts=7):
     """Function that creates predictions from trained model and input data.
 
     Args:
-        x_input (np.ndarray): Time series data inputting the models. Shape = (n_samples, n_features). Usually last few datapoints. Structure depends on X in train function (usually defined in mydatapreprocessing library).
+        x_input (np.ndarray): Time series data inputting the models. Shape = (n_samples, n_features).
+            Usually last few data points. Structure depends on X in train function
+            (usually defined in mydatapreprocessing library).
         model (list, class): Fitted model object from imported library.
         predicts (int, optional): Number of predicted values. Defaults to 7.
 
@@ -170,15 +187,23 @@ def predict(x_input, model, predicts=7):
 
     if model.output_shape == "one_step":
 
-        return one_step_looper(lambda x_input: model.predict(x_input), x_input, predicts, constant=False)
+        return one_step_looper(
+            lambda new_x_input: model.predict(new_x_input),
+            x_input,
+            predicts,
+            constant=False,
+        )
 
     else:
 
         return model.predict(x_input)[0].reshape(-1)
 
 
-def get_all_models(regressors=True, classifiers=True, other_models=True, sklearn_extensions=True):
-    """Create list of around 80 various sklearn models where regressor or classifier is in class name plus some extra models.
+def get_all_models(
+    regressors=True, classifiers=True, other_models=True, sklearn_extensions=True
+):
+    """Create list of around 80 various sklearn models where regressor or classifier is in class name
+    plus some extra models.
     E.g. ["sklearn.ensemble._forest.ExtraTreesRegressor()", "sklearn.ensemble._bagging.BaggingRegressor()", ...]
 
     Note:
@@ -216,9 +241,15 @@ def get_all_models(regressors=True, classifiers=True, other_models=True, sklearn
                 )
 
             if classifiers:
-                models.extend([getattr(module, cls) for cls in module.__all__ if "Classifier" in cls])
+                models.extend(
+                    [
+                        getattr(module, cls)
+                        for cls in module.__all__
+                        if "Classifier" in cls
+                    ]
+                )
 
-        except Exception:
+        except (Exception,):
             pass
 
     if other_models:
@@ -245,7 +276,11 @@ def get_all_models(regressors=True, classifiers=True, other_models=True, sklearn
         ]
 
         models.extend(
-            [getattr(linear_model, cls) for cls in linear_model.__all__ if cls in other_linear_models]
+            [
+                getattr(linear_model, cls)
+                for cls in linear_model.__all__
+                if cls in other_linear_models
+            ]
         )
 
         models.append(sklearn.svm.SVR)
@@ -253,8 +288,15 @@ def get_all_models(regressors=True, classifiers=True, other_models=True, sklearn
     if sklearn_extensions:
         import sklearn_extensions.extreme_learning_machines.elm as elm
 
-        extensions_models = ["ELMClassifier", "ELMRegressor", "GenELMClassifier", "GenELMRegressor"]
+        extensions_models = [
+            "ELMClassifier",
+            "ELMRegressor",
+            "GenELMClassifier",
+            "GenELMRegressor",
+        ]
 
-        models.extend([getattr(elm, cls) for cls in elm.__all__ if cls in extensions_models])
+        models.extend(
+            [getattr(elm, cls) for cls in elm.__all__ if cls in extensions_models]
+        )
 
     return models
